@@ -1,4 +1,3 @@
-import inspect
 import json
 import os
 from pathlib import Path
@@ -6,12 +5,12 @@ from typing import Dict
 
 from ruamel.yaml import YAML
 
-from cognite.air.constants import AIR_DATA_MODEL_NAME, AIR_DATA_PATH_TO_YAML, SA_EXT_ID
+from cognite.air import constants
 from cognite.air.utils import strip_patch_from_version
 
 
 def get_local_testing(data):
-    if SA_EXT_ID in data.keys():
+    if constants.SA_EXT_ID in data.keys():
         return False
     yaml_path = path_to_yaml(data)
     definitions = [i["id"] for i in json.loads(retrieve_field_definitions(yaml_path))]
@@ -22,11 +21,11 @@ def get_local_testing(data):
 
 
 def path_to_yaml(data: Dict) -> Path:
-    if data.get(AIR_DATA_PATH_TO_YAML, False):
-        path_to_yaml = Path(data[AIR_DATA_PATH_TO_YAML])
+    yaml_path = retrieve_local_testing(data, constants.AIR_DATA_PATH_TO_YAML)
+    if yaml_path:
+        return Path(yaml_path)
     else:
-        path_to_yaml = _local_config_path()
-    return path_to_yaml
+        raise ValueError("No path to local config.yaml is given.")
 
 
 def _load_yaml(path: Path) -> Dict:
@@ -35,18 +34,6 @@ def _load_yaml(path: Path) -> Dict:
     return yaml
 
 
-def _local_config_path() -> Path:
-    stack = inspect.stack()
-    function_dir = [f[1] for f in stack if "handler.py" in f[1]][0]
-    function_path = Path(function_dir)
-    while function_path.parts[-1] != "function":
-        function_path = function_path.parent
-        if function_path == Path("/"):
-            raise BaseException("Could not find function folder.")
-    print(function_path)
-    return function_path / Path("config.yaml")
-
-
 def retrieve_field_definitions(path_to_config: Path):
     fields: Dict = _load_yaml(path_to_config).get("fields", {})
     output = []
@@ -61,12 +48,11 @@ def retrieve_backfilling(data):
 
 
 def retrieve_model_name(data: Dict):
-    if data.get(AIR_DATA_MODEL_NAME, False):
-        return data[AIR_DATA_MODEL_NAME]
+    model_name = retrieve_local_testing(data, constants.AIR_DATA_MODEL_NAME, False)
+    if model_name:
+        return model_name
     cwd = os.getcwd()
-    print(cwd)
     model_name = Path(cwd).parent.parent.parts[-1]
-    print(model_name)
     return model_name
 
 
@@ -76,5 +62,24 @@ def retrieve_model_version(data):
     return strip_patch_from_version(model_version)
 
 
+def retrieve_local_testing(data, field, alternative=None):
+    local_test = data.get(constants.AIR_DATA_LOCAL_TESTING)
+    validate_local_test(local_test)
+    value = local_test.get(field)
+    if value is None:
+        return alternative
+    return value
+
+
+def validate_local_test(local_test):
+    if not isinstance(local_test, dict):
+        raise ValueError(f"{constants.AIR_DATA_LOCAL_TESTING} needs to contain a dictionary.")
+    for key in local_test.keys():
+        if key not in constants.AIR_DATA_ALLOWED_KEYS:
+            raise ValueError(f"{key} not a valid field in {constants.AIR_DATA_LOCAL_TESTING}")
+    if constants.AIR_DATA_PATH_TO_YAML not in local_test.keys():
+        raise ValueError(f"No path to local yaml given: {constants.AIR_DATA_PATH_TO_YAML}")
+
+
 def create_fake_backfilling_asset():
     pass
