@@ -25,10 +25,11 @@ class AlertCreator:
     Args:
         air_client (AIRClient): Instance of AIRClient
         merge_period (int): In ms. Maxmimal distance between two valid alerts to have them merged together.
-        minimum_length_of_alert (int): In ms. The length an alert needs to have to be a valid alert.
-        maximumg_length_of_alert (int): In ms. (not implemented) If the alert is longer
-        than this parameter, a new alert will be created.
-        alert_window (int): In ms.
+        minimum_length_of_alert (int): In ms. The length an alert needs to have to be a valid alert (inclusive).
+        maximum_length_of_alert (int): In ms. (not implemented) If the alert is longer
+            than this parameter, a new alert will be created.
+        alert_window (Optional[int]): In ms. If the end of an alert is older than now minus alert_window it will not be
+            stored as an active alert.
 
     """
 
@@ -48,7 +49,7 @@ class AlertCreator:
         self.events_cache: List[Event] = []
 
     def _show_alert(self, start_time: int, end_time: int) -> bool:
-        return end_time - start_time > self.minimum_length_of_alert
+        return end_time - start_time >= self.minimum_length_of_alert
 
     def _send_notification(self, start_time: int, end_time: int) -> bool:
         is_event_fresh = end_time >= current_time_in_ms() - self.alert_window
@@ -158,6 +159,8 @@ class AlertCreator:
     ) -> Tuple[List, List, int]:
         """Create non-overlapping alerts.
 
+        **Note:** alerts with different alert messages will not be merged.
+
         Args:
             df (Union[pd.DataFrame, List[List]): Either pandas DataFrame with a boolean column named "deviation" or
                 a list of lists.
@@ -228,10 +231,7 @@ class AlertCreator:
             new_event (List[int]): A list of two integers denoting start and end time in ms.
             end (int): End time of the evaluation period in ms.
             notification_message (str): A message that is going to be sent to the subscriber.
-            alert_window (int): How old is the event to be allowed to sent a notification?
-                                Defaults to not older than 12 hours.
-            min_length_of_alert (int=0): Minimum length of an interval to be considered for merging.
-            merge_period (int): Maximum distance between intervals to be merged.
+
 
         """
         start_time, end_time = new_event
@@ -267,8 +267,6 @@ class AlertCreator:
             new_events (List[List[int]]): List of lists with two integers. First indicates the start time
             and the second the end time.
             end (int): The last timestamp to consider.
-            min_length_of_alert (int): The minimum length of an alert until which it should be considered.
-            merge_period (int): When events should be merged together.
             notification (str): A string that is going to be sent to the end user and visible in the Front End
 
         Returns:
@@ -351,8 +349,6 @@ class AlertCreator:
         Args:
             event_end (int): The end of the open event.
             new_event (List[int]): List of two integers denoting the start and end of the new event in ms.
-            min_length_of_alert (int): The minimum length of an alert until which it should be considered.
-            merge_period (int): When events should be merged together.
 
         Returns:
             bool: Either if the new event closes the open event (True) or not (False)
@@ -378,7 +374,7 @@ class AlertCreator:
             existing_open_event.end_time = event_end
         if (
             not is_string_truthy(existing_open_event.metadata.get(MTD_SHOW))
-            and event_end - existing_open_event.start_time > self.minimum_length_of_alert
+            and event_end - existing_open_event.start_time >= self.minimum_length_of_alert
         ):
             existing_open_event.metadata[MTD_SHOW] = "True"
         return existing_open_event
