@@ -53,9 +53,7 @@ def pandas_ts_to_unix_ms(ts):
 
     quotient, remainder = divmod(ts.value, 1_000_000)
     if remainder:
-        warnings.warn(
-            f"Loss of resolution during timestamp conversion to 'ms' (-{remainder} ns)", UserWarning,
-        )
+        warnings.warn(f"Loss of resolution during timestamp conversion to 'ms' (-{remainder} ns)", UserWarning)
     return quotient
 
 
